metadata

package
v0.5.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 7, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Strip

func Strip(path string) error

Strip strips metadata (EXIF, text chunks) from image files in place by writing a stripped copy to a temp file and replacing the original. Supported formats: JPEG, PNG.

Types

This section is empty.

Jump to