Discover Packages
github.com/bethropolis/localgo
pkg
storage
package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jul 6, 2025
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
EnsureDirExists creates a directory if it doesn't exist.
SaveStreamToFile saves an io.Reader stream to a specified file path.
It creates necessary directories.
It reports progress via the onProgress callback (bytes written).
type ProgressWriter struct {
Writer io .Writer
BytesWritten int64
OnProgress func(bytesWritten int64 )
}
ProgressWriter is a wrapper around io.Writer that calls a callback on Write.
Write implements the io.Writer interface.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.